==> xfree86_4.1.0.orig.tar.gz: xc/lib/Xmu/Xmu-def.cpp <==
LIBRARY libXmu
VERSION LIBRARY_VERSION
EXPORTS
XmuAllStandardColormaps
XmuGetAtomName
XmuInternAtom
XmuInternStrings
XmuMakeAtom
XmuNameOfAtom
XmuClientWindow
XmuAddCloseDisplayHook
XmuLookupCloseDisplayHook
XmuRemoveCloseDisplayHook
XmuGetColormapAllocation
XmuCreateColormap
XmuCreatePixmapFromBitmap
XmuCursorNameToIndex
_XmuCCLookupDisplay
XmuConvertStandardSelection
XmuPrintDefaultErrorMessage
XmuSimpleErrorHandler
XmuDeleteStandardColormap
XmuDQAddDisplay
XmuDQCreate
XmuDQDestroy
XmuDQLookupDisplay
XmuDQRemoveDisplay
XmuDistinguishableColors
XmuDistinguishablePixels
XmuDrawLogo
XmuDrawRoundedRectangle
XmuFillRoundedRectangle
_XEditResCheckMessages
_XEditResGet16
_XEditResGet32
_XEditResGet8
_XEditResGetSigned16
_XEditResGetString8
_XEditResGetWidgetInfo
_XEditResPut16
_XEditResPut32
_XEditResPut8
_XEditResPutString8
_XEditResPutWidgetInfo
_XEditResResetStream
XmuRegisterExternalAgent
XmuCvtFunctionToCallback
XmuGetHostname
XmuCreateStippledPixmap
XmuReleaseStippledPixmap
XmuAddInitializer
XmuCallInitializers
XmuLocateBitmapFile
XmuLocatePixmapFile
_XmuStringToBitmapFreeCache
_XmuStringToBitmapInitCache
XmuLookupAPL
XmuLookupArabic
XmuLookupCyrillic
XmuLookupGreek
XmuLookupHebrew
XmuLookupJISX0201
XmuLookupKana
XmuLookupLatin1
XmuLookupLatin2
XmuLookupLatin3
XmuLookupLatin4
XmuLookupString
XmuLookupStandardColormap
XmuCompareISOLatin1
XmuCopyISOLatin1Lowered
XmuCopyISOLatin1Uppered
XmuReadBitmapData
XmuReadBitmapDataFromFile
XmuScreenOfWindow
XmuReshapeWidget
XmuStandardColormap
XmuCvtStringToBackingStore
XmuCvtStringToBitmap
XmuCvtStringToColorCursor
XmuCvtStringToCursor
XmuCvtStringToGravity
XmuCvtStringToJustify
XmuCvtStringToLong
XmuCvtStringToOrientation
XmuCvtStringToShapeStyle
XmuCvtStringToWidget
XmuNewCvtStringToWidget
XmuUpdateMapHints
XmuVisualStandardColormaps
XmuWnCountOwnedResources
XmuWnFetchResources
XmuWnInitializeNodes
XmuWnNameToNode
XctCreate
XctFree
XctNextItem
XctReset

/* $XFree86$ */

==> xfree86_4.3.0.dfsg.1.orig.tar.gz: xc/lib/Xmu/Xmu-def.cpp <==
LIBRARY libXmu
VERSION LIBRARY_VERSION
EXPORTS
XmuAllStandardColormaps
XmuGetAtomName
XmuInternAtom
XmuInternStrings
XmuMakeAtom
XmuNameOfAtom
XmuClientWindow
XmuAddCloseDisplayHook
XmuLookupCloseDisplayHook
XmuRemoveCloseDisplayHook
XmuGetColormapAllocation
XmuCreateColormap
XmuCreatePixmapFromBitmap
XmuCursorNameToIndex
_XmuCCLookupDisplay
XmuConvertStandardSelection
XmuPrintDefaultErrorMessage
XmuSimpleErrorHandler
XmuDeleteStandardColormap
XmuDQAddDisplay
XmuDQCreate
XmuDQDestroy
XmuDQLookupDisplay
XmuDQRemoveDisplay
XmuDistinguishableColors
XmuDistinguishablePixels
XmuDrawLogo
XmuDrawRoundedRectangle
XmuFillRoundedRectangle
_XEditResCheckMessages
_XEditResGet16
_XEditResGet32
_XEditResGet8
_XEditResGetSigned16
_XEditResGetString8
_XEditResGetWidgetInfo
_XEditResPut16
_XEditResPut32
_XEditResPut8
_XEditResPutString8
_XEditResPutWidgetInfo
_XEditResResetStream
XmuRegisterExternalAgent
XmuCvtFunctionToCallback
XmuGetHostname
XmuCreateStippledPixmap
XmuReleaseStippledPixmap
XmuAddInitializer
XmuCallInitializers
XmuLocateBitmapFile
XmuLocatePixmapFile
_XmuStringToBitmapFreeCache
_XmuStringToBitmapInitCache
XmuLookupAPL
XmuLookupArabic
XmuLookupCyrillic
XmuLookupGreek
XmuLookupHebrew
XmuLookupJISX0201
XmuLookupKana
XmuLookupLatin1
XmuLookupLatin2
XmuLookupLatin3
XmuLookupLatin4
XmuLookupString
XmuLookupStandardColormap
XmuCompareISOLatin1
XmuCopyISOLatin1Lowered
XmuCopyISOLatin1Uppered
XmuReadBitmapData
XmuReadBitmapDataFromFile
XmuScreenOfWindow
XmuReshapeWidget
XmuStandardColormap
XmuCvtStringToBackingStore
XmuCvtStringToBitmap
XmuCvtStringToColorCursor
XmuCvtStringToCursor
XmuCvtStringToGravity
XmuCvtStringToJustify
XmuCvtStringToLong
XmuCvtStringToOrientation
XmuCvtStringToShapeStyle
XmuCvtStringToWidget
XmuNewCvtStringToWidget
XmuUpdateMapHints
XmuVisualStandardColormaps
XmuWnCountOwnedResources
XmuWnFetchResources
XmuWnInitializeNodes
XmuWnNameToNode
XctCreate
XctFree
XctNextItem
XctReset
XmuCvtGravityToString
XmuCvtBackingStoreToString
_XA_ATOM_PAIR
_XA_CHARACTER_POSITION
_XA_CLASS
_XA_CLIENT_WINDOW
_XA_CLIPBOARD
_XA_COMPOUND_TEXT
_XA_DECNET_ADDRESS
_XA_DELETE
_XA_FILENAME
_XA_HOSTNAME
_XA_IP_ADDRESS
_XA_LENGTH
_XA_LIST_LENGTH
_XA_NAME
_XA_NET_ADDRESS
_XA_NULL
_XA_OWNER_OS
_XA_SPAN
_XA_TARGETS
_XA_TEXT
_XA_TIMESTAMP
_XA_USER
_XA_UTF8_STRING
XmuNewArea
XmuDestroyScanlineList
XmuCvtWidgetToString
XmuOptimizeScanline
XmuAreaOrXor
XmuScanlineXor
XmuDestroySegmentList
XmuCvtJustifyToString
XmuSnprintf
XmuNewScanline
XmuNCopyISOLatin1Lowered
XmuNCopyISOLatin1Uppered
XmuCvtShapeStyleToString
XmuCvtOrientationToString
XmuScanlineOrSegment
#ifdef __UNIXOS2__
XmuScanlineNot
XmuScanlineAnd
XmuScanlineOr
#endif

/* $XFree86: xc/lib/Xmu/Xmu-def.cpp,v 1.2 2002/05/31 18:45:45 dawes Exp $ */
